@@ -1,9 +1,9 @@
 import xmlrpclib
 import base64
 
-from gtk import TRUE, FALSE
 import gconf
 
+
 import gettext
 _ = gettext.gettext
 
@@ -17,17 +17,17 @@ class Blog(bloggerAPI.Blog):
         bloggerAPI.Blog.__init__(self)
 
     def postEntry (self, username, password, base_url, title,
-                   entry, client, gconf_prefix):
+                   entry, keywords, client, gconf_prefix):
 
         url = self._getURL(base_url, client, gconf_prefix)
 
         if (base_url == None):
             hig_alert.reportError("Could not post Blog entry", "No XML-RPC server URL to post blog entries to is set, or the value could not be retrieved from GConf. Your entry will remain in the blogger window.")
-            return FALSE
+            return False
 
         blog_id  = client.get_string(gconf_prefix + "/blog_id")
 
-        success = TRUE
+        success = True
 
         #check for GNOME proxy configurations and use if required
         proxy_transport = proxy.GnomeProxyTransport(client)
@@ -36,20 +36,19 @@ class Blog(bloggerAPI.Blog):
         content = {}
         content['title'] = title
         content['description'] = entry
+	content['mt_keywords'] = keywords
 
         try:
             server.metaWeblog.newPost(blog_id, username, password, content, xmlrpclib.True)
         except xmlrpclib.Fault, e:
             hig_alert.handleBloggerAPIFault(e, "Could not post blog entry", username, blog_id, url)
-            success = FALSE
+            success = False
         except xmlrpclib.ResponseError, e:
-            print "ResponseError"
-            print e
-            hig_alert.reportError("Could not post Blog entry", 'Received an invalid response: %s.' % (url, hig_alert.italic(e)))
-            success = FALSE            
+            hig_alert.reportError("Could not post Blog entry", 'Received an invalid response: %s posting to URL %s.' % (hig_alert.italic(e), url))
+            success = False
         except xmlrpclib.ProtocolError, e:
             hig_alert.reportError("Could not post Blog entry", 'URL \'%s\' does not seem to be a valid bloggerAPI XML-RPC server. Web server reported: %s.' % (url, hig_alert.italic(e.errmsg)))
-            success = FALSE
+            success = False
 
         return success
 
@@ -60,7 +59,7 @@ class Blog(bloggerAPI.Blog):
 
         blog_id  = client.get_string(gconf_prefix + "/blog_id")
 
-        success = TRUE
+        success = True
         
         #check for GNOME proxy configurations and use if required
         proxy_transport = proxy.GnomeProxyTransport(client)
@@ -69,7 +68,7 @@ class Blog(bloggerAPI.Blog):
         content = {}
         content['name'] = file_name
         content['type'] = mime_type
-        content['bits'] = base64.encodestring(file_contents)
+        content['bits'] = xmlrpclib.Binary(file_contents)
 
         imageurl = None
 
